MethodChannelEmvnfc class

An implementation of EmvnfcPlatform that uses method channels.

Inheritance

Constructors

MethodChannelEmvnfc()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
monitorStream Stream<TransactionMonitor>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() Future<void>
override
getPlatformVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCardListening({required String amountText, required String licenseKey, Duration timeout = const Duration(seconds: 60)}) Future<void>
override
submitPin(String pin) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited