EmvnfcPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • EmvnfcPlatform
Implementers

Constructors

EmvnfcPlatform()
Constructs a EmvnfcPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
monitorStream Stream<TransactionMonitor>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() Future<void>
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCardListening({required String amountText, required String licenseKey, Duration timeout = const Duration(seconds: 60)}) Future<void>
submitPin(String pin) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EmvnfcPlatform
The default instance of EmvnfcPlatform to use.
getter/setter pair