EmvnfcWeb class
A web implementation of the EmvnfcPlatform of the Emvnfc plugin.
- Inheritance
-
- Object
- PlatformInterface
- EmvnfcPlatform
- EmvnfcWeb
Constructors
- EmvnfcWeb()
- Constructs a EmvnfcWeb
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
monitorStream
→ Stream<
TransactionMonitor> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → Future< void> -
inherited
-
getPlatformVersion(
) → Future< String?> -
Returns a String containing the version of the platform.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startCardListening(
{required String amountText, required String licenseKey, Duration timeout = const Duration(seconds: 60)}) → Future< void> -
inherited
-
submitPin(
String pin) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void